@@ -1,6 +1,6 @@
 package DBIx::Lite::ResultSet;
 {
-  $DBIx::Lite::ResultSet::VERSION = '0.13';
+  $DBIx::Lite::ResultSet::VERSION = '0.14';
 }
 use strict;
 use warnings;
@@ -31,11 +31,11 @@ sub _new {
     };
     
     for (qw(dbix_lite table)) {
-        $self->{$_} = delete $params{$_} or die "$_ argument needed\n";
+        $self->{$_} = delete $params{$_} or croak "$_ argument needed";
     }
     
     !%params
-        or die "Unknown options: " . join(', ', keys %params) . "\n";
+        or croak "Unknown options: " . join(', ', keys %params);
     
     bless $self, $class;
     $self;
@@ -185,7 +185,7 @@ sub select_sth {
 sub insert_sql {
     my $self = shift;
     my $insert_cols = shift;
-    ref $insert_cols eq 'HASH' or die "insert_sql() requires a hashref\n";
+    ref $insert_cols eq 'HASH' or croak "insert_sql() requires a hashref";
     
     return $self->{dbix_lite}->{abstract}->insert(
         $self->{table}{name}, $insert_cols,
@@ -195,7 +195,7 @@ sub insert_sql {
 sub insert_sth {
     my $self = shift;
     my $insert_cols = shift;
-    ref $insert_cols eq 'HASH' or die "insert_sth() requires a hashref\n";
+    ref $insert_cols eq 'HASH' or croak "insert_sth() requires a hashref";
     
     my ($sql, @bind) = $self->insert_sql($insert_cols);
     return $self->{dbix_lite}->dbh->prepare($sql) || undef, @bind;
@@ -204,7 +204,7 @@ sub insert_sth {
 sub insert {
     my $self = shift;
     my $insert_cols = shift;
-    ref $insert_cols eq 'HASH' or die "insert() requires a hashref\n";
+    ref $insert_cols eq 'HASH' or croak "insert() requires a hashref";
     
     my $res;
     $self->{dbix_lite}->dbh_do(sub {
@@ -224,15 +224,15 @@ sub insert {
 sub update_sql {
     my $self = shift;
     my $update_cols = shift;
-    ref $update_cols eq 'HASH' or die "update_sql() requires a hashref\n";
+    ref $update_cols eq 'HASH' or croak "update_sql() requires a hashref";
     
     my $update_where = { -and => $self->{where} };
     
     if ($self->{cur_table}{name} ne $self->{table}{name}) {
         my @pk = $self->{cur_table}->pk
-            or die "No primary key defined for " . $self->{cur_table}{name} . "; cannot update using relationships\n";
+            or croak "No primary key defined for " . $self->{cur_table}{name} . "; cannot update using relationships";
         @pk == 1
-            or die "Update across relationships is not allowed with multi-column primary keys\n";
+            or croak "Update across relationships is not allowed with multi-column primary keys";
         
         my $fq_pk = $self->_table_prefix($self->{cur_table}{name}) . "." . $pk[0];
         $update_where = {
@@ -251,7 +251,7 @@ sub update_sql {
 sub update_sth {
     my $self = shift;
     my $update_cols = shift;
-    ref $update_cols eq 'HASH' or die "update_sth() requires a hashref\n";
+    ref $update_cols eq 'HASH' or croak "update_sth() requires a hashref";
     
     my ($sql, @bind) = $self->update_sql($update_cols);
     return $self->{dbix_lite}->dbh->prepare($sql) || undef, @bind;
@@ -260,7 +260,7 @@ sub update_sth {
 sub update {
     my $self = shift;
     my $update_cols = shift;
-    ref $update_cols eq 'HASH' or die "update() requires a hashref\n";
+    ref $update_cols eq 'HASH' or croak "update() requires a hashref";
     
     my $res;
     $self->{dbix_lite}->dbh_do(sub {
@@ -273,7 +273,7 @@ sub update {
 sub find_or_insert {
     my $self = shift;
     my $cols = shift;
-    ref $cols eq 'HASH' or die "find_or_insert() requires a hashref\n";
+    ref $cols eq 'HASH' or croak "find_or_insert() requires a hashref";
     
     my $object;
     $self->{dbix_lite}->txn(sub {
@@ -291,9 +291,9 @@ sub delete_sql {
     
     if ($self->{cur_table}{name} ne $self->{table}{name}) {
         my @pk = $self->{cur_table}->pk
-            or die "No primary key defined for " . $self->{cur_table}{name} . "; cannot delete using relationships\n";
+            or croak "No primary key defined for " . $self->{cur_table}{name} . "; cannot delete using relationships";
         @pk == 1
-            or die "Delete across relationships is not allowed with multi-column primary keys\n";
+            or croak "Delete across relationships is not allowed with multi-column primary keys";
         
         my $fq_pk = $self->_table_prefix($self->{cur_table}{name}) . "." . $pk[0];
         $delete_where = {
@@ -337,6 +337,18 @@ sub single {
     return $row ? $self->_inflate_row($row) : undef;
 }
 
+sub single_value {
+    my $self = shift;
+    
+    my $value;
+    $self->{dbix_lite}->dbh_do(sub {
+        my ($sth, @bind) = $self->select_sth;
+        $sth->execute(@bind);
+        ($value) = $sth->fetchrow_array;
+    });
+    return $value;
+}
+
 sub all {
     my $self = shift;
     
@@ -376,7 +388,7 @@ sub count {
 
 sub get_column {
     my $self = shift;
-    my $column_name = shift or die "get_column() requires a column name";
+    my $column_name = shift or croak "get_column() requires a column name";
     
     my @values = ();
     $self->{dbix_lite}->dbh_do(sub {
@@ -445,7 +457,7 @@ sub AUTOLOAD {
         return $new_self;
     }
     
-    die "No $method method is provided by this " . ref($self) . " object\n";
+    croak "No $method method is provided by this " . ref($self) . " object";
 }
 
 sub DESTROY {}
@@ -462,7 +474,7 @@ DBIx::Lite::ResultSet
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 OVERVIEW
 
@@ -646,6 +658,13 @@ retrieve that column only and it will return a list with the values.
 
     my @book_titles = $books_rs->get_column('title');
 
+=head2 single_value
+
+This method returns the value of the first cell of the first row. It's useful in
+situations like this:
+
+    my $max = $books_rs->select(\"MAX(pages)")->single_value;
+
 =head1 MANIPULATING ROWS
 
 =head2 insert
