@@ -1,10 +1,11 @@
 package DBIx::Lite::Row;
 {
-  $DBIx::Lite::Row::VERSION = '0.13';
+  $DBIx::Lite::Row::VERSION = '0.14';
 }
 use strict;
 use warnings;
 
+use Carp qw(croak);
 use Clone qw(clone);
 use vars qw($AUTOLOAD);
 $Carp::Internal{$_}++ for __PACKAGE__;
@@ -16,11 +17,11 @@ sub _new {
     my $self = {};
     
     for (qw(dbix_lite table data)) {
-        $self->{$_} = delete $params{$_} or die "$_ argument needed\n";
+        $self->{$_} = delete $params{$_} or croak "$_ argument needed";
     }
     
     !%params
-        or die "Unknown options: " . join(', ', keys %params) . "\n";
+        or croak "Unknown options: " . join(', ', keys %params);
     
     bless $self, $class;
     $self;
@@ -30,10 +31,10 @@ sub pk {
     my $self = shift;
     
     my @keys = $self->{table}->pk
-        or die "No primary key defined for table " . $self->{table}{name} . "\n";
+        or croak "No primary key defined for table " . $self->{table}{name};
     
     grep(!exists $self->{data}{$_}, @keys)
-        and die "No primary key data retrieved for table " . $self->{table}{name} . "\n";
+        and croak "No primary key data retrieved for table " . $self->{table}{name};
     
     return { map +($_ => $self->{data}{$_}), @keys };
 }
@@ -46,7 +47,7 @@ sub hashref {
 
 sub update {
     my $self = shift;
-    my $update_cols = shift or die "update() requires a hashref\n";
+    my $update_cols = shift or croak "update() requires a hashref";
     
     $self->{dbix_lite}->table($self->{table}{name})->search($self->pk)->update($update_cols);
     $self->{data}{$_} = $update_cols->{$_} for keys %$update_cols;
@@ -56,16 +57,17 @@ sub update {
 sub delete {
     my $self = shift;
     
-    $self->{dbix_lite}->table($self->{table}{name})->find($self->pk)->delete;
+    $self->{dbix_lite}->table($self->{table}{name})->search($self->pk)->delete;
     undef $self;
 }
 
 sub insert_related {
     my $self = shift;
     my ($rel_name, $insert_cols) = @_;
-    $rel_name or die "insert_related() requires a table name\n";
+    $rel_name or croak "insert_related() requires a table name";
     
-    my ($table_name, $my_key, $their_key) = $self->_relationship($rel_name);
+    my ($table_name, $my_key, $their_key) = $self->_relationship($rel_name)
+        or croak "No $rel_name relationship defined for " . $self->{table}{name};
     
     return $self->{dbix_lite}
         ->table($table_name)
@@ -77,20 +79,20 @@ sub _relationship {
     my ($rel_name) = @_;
     
     my ($rel_type) = grep $self->{table}{$_}{$rel_name}, qw(has_one has_many)
-        or die "No $rel_name relationship defined for " . $self->{table}{name} . "\n";
+        or return ();
     
     my $rel = $self->{table}{$rel_type}{$rel_name};
     my ($table_name, $my_key, $their_key) = ($rel->[0], %{ $rel->[1] });
     
     exists $self->{data}{$my_key}
-        or die "No $my_key key retrieved from " . $self->{table}{name} . "\n";
+        or croak "No $my_key key retrieved from " . $self->{table}{name};
     
     return ($table_name, $my_key, $their_key, $rel_type);
 }
 
 sub get {
     my $self = shift;
-    my $key = shift or die "get() requires a column name\n";
+    my $key = shift or croak "get() requires a column name";
     return $self->{data}{$key};
 }
 
@@ -111,7 +113,7 @@ sub AUTOLOAD {
         return $rel_type eq 'has_many' ? $rs : $rs->single;
     }
     
-    die sprintf "No %s method is provided by this %s (%s) object\n",
+    croak sprintf "No %s method is provided by this %s (%s) object",
         $method, ref($self), $self->{table}{name};
 }
 
@@ -129,7 +131,7 @@ DBIx::Lite::Row
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 OVERVIEW
 
